Module capture

Module capture 

Contains the main capture functionality, including the crate::capture::GraphicsCaptureApiHandler trait and related types.

Structs

CaptureControl
Used to control the capture session
Context
The context provided to the capture handler.

Enums

CaptureControlError
Errors that can occur while controlling a running capture session via CaptureControl.
GraphicsCaptureApiError
Errors that can occur while initializing and running the Windows Graphics Capture pipeline.

Traits

GraphicsCaptureApiHandler
Trait implemented by types that handle graphics capture events.