CaptureControl

Struct CaptureControl 

pub struct CaptureControl<T: GraphicsCaptureApiHandler + Send + 'static, E> { /* private fields */ }
Used to control the capture session

Implementations

Source

impl<T: GraphicsCaptureApiHandler + Send + 'static, E> CaptureControl<T, E>

pub const fn new( thread_handle: JoinHandle<Result<(), GraphicsCaptureApiError<E>>>, halt_handle: Arc<AtomicBool>, callback: Arc<Mutex<T>>, ) -> Self

Constructs a new CaptureControl.

pub fn is_finished(&self) -> bool

Checks whether the capture thread has finished.

pub fn into_thread_handle( self, ) -> JoinHandle<Result<(), GraphicsCaptureApiError<E>>>

Gets the join handle for the capture thread.

pub fn halt_handle(&self) -> Arc<AtomicBool> ⓘ

Gets the halt handle used to pause the capture thread.

pub fn callback(&self) -> Arc<Mutex<T>> ⓘ

Gets the callback struct used to call struct methods directly.

pub fn wait(self) -> Result<(), CaptureControlError<E>>

Waits for the capture thread to stop.

Errors
pub fn stop(self) -> Result<(), CaptureControlError<E>>

Gracefully requests the capture thread to stop and waits for it to finish.

This posts a WM_QUIT to the capture thread and joins it.

Errors