pub enum Error {
FeatureLevelNotSatisfied,
WindowsError(Error),
}Expand description
Errors that can occur when creating or working with Direct3D devices and textures.
Variants
FeatureLevelNotSatisfied
The created device does not support at least feature level 11.0.
WindowsError(Error)
A Windows Runtime/Win32 API call failed.
Wraps windows::core::Error.