FrameBuffer

Struct FrameBuffer 

pub struct FrameBuffer<'a> { /* private fields */ }
Represents a frame buffer containing pixel data.

Example

ⓘ
// Get a frame from the capture session
let mut buffer = frame.buffer()?;
buffer.save_as_image("screenshot.png", ImageFormat::Png)?;

Implementations

Source

impl<'a> FrameBuffer<'a>

pub const fn new( raw_buffer: &'a mut [u8], width: u32, height: u32, row_pitch: u32, depth_pitch: u32, color_format: ColorFormat, ) -> Self

Constructs a new FrameBuffer.

pub const fn width(&self) -> u32

Gets the width of the frame buffer.

pub const fn height(&self) -> u32

Gets the height of the frame buffer.

pub const fn row_pitch(&self) -> u32

Gets the row pitch of the frame buffer.

pub const fn depth_pitch(&self) -> u32

Gets the depth pitch of the frame buffer.

pub const fn color_format(&self) -> ColorFormat

Gets the color format of the frame buffer.

pub const fn has_padding(&self) -> bool

Checks if the buffer has padding.

pub const fn as_raw_buffer(&mut self) -> &mut [u8] ⓘ

Gets the raw pixel data, which may include padding.

pub fn as_nopadding_buffer<'b>(&'b self, buffer: &'b mut Vec<u8>) -> &'b [u8] ⓘ

Gets the pixel data without padding.

pub fn save_as_image<T: AsRef<Path>>( &mut self, path: T, format: ImageFormat, ) -> Result<(), Error>

Saves the frame buffer as an image to the specified path.