pub enum DrawBorderSettings {
Default,
WithBorder,
WithoutBorder,
}Expand description
Defines whether a border should be drawn around the captured item.
Variants
Default
Use the system’s default behavior for the capture border.
WithBorder
Draw a border around the captured item.
WithoutBorder
Do not draw a border around the captured item.