Contains the main capture functionality, including the
crate::capture::GraphicsCaptureApiHandler trait and related types.
Structs
- Capture
Control - Used to control the capture session
- Context
- The context provided to the capture handler.
Enums
- Capture
Control Error - Errors that can occur while controlling a running capture session via
CaptureControl. - Graphics
Capture ApiError - Errors that can occur while initializing and running the Windows Graphics Capture pipeline.
Traits
- Graphics
Capture ApiHandler - Trait implemented by types that handle graphics capture events.