GraphicsCaptureApiError

Enum GraphicsCaptureApiError 

pub enum GraphicsCaptureApiError<E> {
    FailedToJoinThread,
    FailedToInitWinRT,
    FailedToCreateDispatcherQueueController,
    FailedToShutdownDispatcherQueue,
    FailedToSetDispatcherQueueCompletedHandler,
    FailedToRunMessageLoop,
    FailedToStartCaptureThread,
    ItemConvertFailed,
    DirectXError(Error),
    GraphicsCaptureApiError(Error),
    NewHandlerError(E),
    FrameHandlerError(E),
}
Errors that can occur while initializing and running the Windows Graphics Capture pipeline.

Variants



FailedToJoinThread

Joining the worker thread failed (panic or OS-level join error).



FailedToInitWinRT

Failed to initialize the Windows Runtime for multithreaded apartment.

Occurs when RoInitialize(RO_INIT_MULTITHREADED) returns an error other than S_FALSE.



FailedToCreateDispatcherQueueController

Creating the dispatcher queue controller for the message loop failed.



FailedToShutdownDispatcherQueue

Shutting down the dispatcher queue failed.



FailedToSetDispatcherQueueCompletedHandler

Registering the dispatcher queue completion handler failed.



FailedToRunMessageLoop

The Windows message loop for the capture thread failed.



FailedToStartCaptureThread

The free-threaded capture worker exited before publishing its control handles.



ItemConvertFailed

The provided item could not be converted into a GraphicsCaptureItem.

This happens when [crate::settings::TryIntoCaptureItemWithDetails::try_into_capture_item_with_details] fails for the item passed in crate::settings::Settings.



DirectXError(Error)

Underlying Direct3D (D3D11) error.

Wraps crate::d3d11::Error.



GraphicsCaptureApiError(Error)

Error produced by the Windows Graphics Capture API wrapper.

Wraps crate::graphics_capture_api::Error.



NewHandlerError(E)

Error returned by the user handler when constructing it via GraphicsCaptureApiHandler::new.



FrameHandlerError(E)

Error returned by the user handler during frame processing via GraphicsCaptureApiHandler::on_frame_arrived or from GraphicsCaptureApiHandler::on_closed.