pub struct CaptureControl<T: GraphicsCaptureApiHandler + Send + 'static, E> { /* private fields */ }Expand description
Used to control the capture session
Implementations
Sourceimpl<T: GraphicsCaptureApiHandler + Send + 'static, E> CaptureControl<T, E>
impl<T: GraphicsCaptureApiHandler + Send + 'static, E> CaptureControl<T, E>
Sourcepub const fn new(
thread_handle: JoinHandle<Result<(), GraphicsCaptureApiError<E>>>,
halt_handle: Arc<AtomicBool>,
callback: Arc<Mutex<T>>,
) -> Self
pub const fn new( thread_handle: JoinHandle<Result<(), GraphicsCaptureApiError<E>>>, halt_handle: Arc<AtomicBool>, callback: Arc<Mutex<T>>, ) -> Self
Constructs a new CaptureControl.
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Checks whether the capture thread has finished.
Sourcepub fn into_thread_handle(
self,
) -> JoinHandle<Result<(), GraphicsCaptureApiError<E>>>
pub fn into_thread_handle( self, ) -> JoinHandle<Result<(), GraphicsCaptureApiError<E>>>
Gets the join handle for the capture thread.
Sourcepub fn halt_handle(&self) -> Arc<AtomicBool> ⓘ
pub fn halt_handle(&self) -> Arc<AtomicBool> ⓘ
Gets the halt handle used to pause the capture thread.
Sourcepub fn callback(&self) -> Arc<Mutex<T>> ⓘ
pub fn callback(&self) -> Arc<Mutex<T>> ⓘ
Gets the callback struct used to call struct methods directly.
Sourcepub fn wait(self) -> Result<(), CaptureControlError<E>>
pub fn wait(self) -> Result<(), CaptureControlError<E>>
Waits for the capture thread to stop.
Errors
CaptureControlError::FailedToJoinThreadwhen joining the internal thread failsCaptureControlError::ThreadHandleIsTakenwhen the thread handle was previously taken viaCaptureControl::into_thread_handle
Sourcepub fn stop(self) -> Result<(), CaptureControlError<E>>
pub fn stop(self) -> Result<(), CaptureControlError<E>>
Gracefully requests the capture thread to stop and waits for it to finish.
This posts a WM_QUIT to the capture thread and joins it.
Errors
CaptureControlError::FailedToPostThreadMessagewhen posting WM_QUIT to the thread fails and the thread is still runningCaptureControlError::FailedToJoinThreadwhen joining the internal thread failsCaptureControlError::ThreadHandleIsTakenwhen the thread handle was previously taken viaCaptureControl::into_thread_handle