Error

Enum Error 

pub enum Error {
    InvalidSize,
    InvalidTitleBarSize,
    UnsupportedFormat,
    ImageEncoderError(ImageEncoderError),
    IoError(Error),
    WindowsError(Error),
}
Errors that can occur while working with captured frames and buffers.

Variants



InvalidSize

The crop rectangle is invalid (start >= end on either axis).



InvalidTitleBarSize

The configured title bar height is invalid (greater than or equal to the frame height).



UnsupportedFormat

The current ColorFormat cannot be saved as an image.



ImageEncoderError(ImageEncoderError)

Image encoding failed.

Wraps crate::encoder::ImageEncoderError.



IoError(Error)

An I/O error occurred while writing the image to disk.

Wraps std::io::Error.



WindowsError(Error)

A Windows API call failed.

Wraps windows::core::Error.